==> sumo_1.15.0+dfsg.orig.tar.xz: sumo-1_15_0/tests/netedit/additionalelements/basic/additional_refposinvalid/test.py <==
#!/usr/bin/env python
# Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
# Copyright (C) 2009-2022 German Aerospace Center (DLR) and others.
# This program and the accompanying materials are made available under the
# terms of the Eclipse Public License 2.0 which is available at
# https://www.eclipse.org/legal/epl-2.0/
# This Source Code may also be made available under the following Secondary
# Licenses when the conditions for such availability set forth in the Eclipse
# Public License 2.0 are satisfied: GNU General Public License, version 2
# or later which is available at
# https://www.gnu.org/licenses/old-licenses/gpl-2.0-standalone.html
# SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later

# @file    test.py
# @author  Pablo Alvarez Lopez
# @date    2017-03-12

# import common functions for netedit tests
import os
import sys

testRoot = os.path.join(os.environ.get('SUMO_HOME', '.'), 'tests')
neteditTestRoot = os.path.join(
    os.environ.get('TEXTTEST_HOME', testRoot), 'netedit')
sys.path.append(neteditTestRoot)
import neteditTestFunctions as netedit  # noqa

# Open netedit
neteditProcess, referencePosition = netedit.setupAndStart(neteditTestRoot)

# force save additionals
netedit.forceSaveAdditionals()

# go to additional mode
netedit.additionalMode()

# select busStop
netedit.changeElement("busStop")

# set invalid reference (dummy)
netedit.changeDefaultValue(netedit.attrs.busStop.create.references, "dummy reference")

# try to create busStop with the dummy reference
netedit.leftClick(referencePosition, 240, 250)

# set valid reference
netedit.changeDefaultValue(netedit.attrs.busStop.create.references, "reference right")

# create busStop with the valid reference
netedit.leftClick(referencePosition, 300, 250)

# save additionals
netedit.saveAdditionals(referencePosition)

# save network
netedit.saveNetwork(referencePosition)

# quit netedit
netedit.quit(neteditProcess)

==> sumo_1.18.0+dfsg.orig.tar.xz: sumo-1_18_0/tests/netedit/additionalelements/basic/additional_refposinvalid/test.py <==
#!/usr/bin/env python
# Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.dev/sumo
# Copyright (C) 2009-2023 German Aerospace Center (DLR) and others.
# This program and the accompanying materials are made available under the
# terms of the Eclipse Public License 2.0 which is available at
# https://www.eclipse.org/legal/epl-2.0/
# This Source Code may also be made available under the following Secondary
# Licenses when the conditions for such availability set forth in the Eclipse
# Public License 2.0 are satisfied: GNU General Public License, version 2
# or later which is available at
# https://www.gnu.org/licenses/old-licenses/gpl-2.0-standalone.html
# SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later

# @file    test.py
# @author  Pablo Alvarez Lopez
# @date    2017-03-12

# import common functions for netedit tests
import os
import sys

testRoot = os.path.join(os.environ.get('SUMO_HOME', '.'), 'tests')
neteditTestRoot = os.path.join(
    os.environ.get('TEXTTEST_HOME', testRoot), 'netedit')
sys.path.append(neteditTestRoot)
import neteditTestFunctions as netedit  # noqa

# Open netedit
neteditProcess, referencePosition = netedit.setupAndStart(neteditTestRoot)

# go to additional mode
netedit.additionalMode()

# select busStop
netedit.changeElement("busStop")

# set invalid reference (dummy)
netedit.changeDefaultValue(netedit.attrs.busStop.create.references, "dummy reference")

# try to create busStop with the dummy reference
netedit.leftClick(referencePosition, 451, 210)

# set valid reference
netedit.changeDefaultValue(netedit.attrs.busStop.create.references, "reference right")

# create busStop with the valid reference
netedit.leftClick(referencePosition, 451, 210)

# save netedit config
netedit.saveNeteditConfig(referencePosition)

# quit netedit
netedit.quit(neteditProcess)
